You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/11 14:14:25 UTC

[48/51] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/client/integration/GridClientAbstractSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/client/integration/GridClientAbstractSelfTest.java b/modules/clients/src/test/java/org/gridgain/client/integration/GridClientAbstractSelfTest.java
index e6d74aa..f10b9d5 100644
--- a/modules/clients/src/test/java/org/gridgain/client/integration/GridClientAbstractSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/client/integration/GridClientAbstractSelfTest.java
@@ -11,19 +11,19 @@ package org.gridgain.client.integration;
 
 import junit.framework.*;
 import net.sf.json.*;
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
+import org.apache.ignite.spi.discovery.tcp.*;
+import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
+import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
+import org.apache.ignite.spi.swapspace.file.*;
 import org.gridgain.client.*;
 import org.gridgain.client.ssl.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.affinity.consistenthash.*;
 import org.gridgain.grid.cache.store.*;
-import org.apache.ignite.spi.discovery.tcp.*;
-import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
-import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
-import org.apache.ignite.spi.swapspace.file.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.junits.common.*;
@@ -1435,7 +1435,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
     private static class TestTask extends ComputeTaskSplitAdapter<List<Object>, Integer> {
         /** {@inheritDoc} */
         @Override protected Collection<? extends ComputeJob> split(int gridSize, List<Object> list)
-            throws GridException {
+            throws IgniteCheckedException {
             Collection<ComputeJobAdapter> jobs = new ArrayList<>();
 
             if (list != null)
@@ -1457,7 +1457,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             int sum = 0;
 
             for (ComputeJobResult res : results)
@@ -1473,7 +1473,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
     private static class SleepTestTask extends ComputeTaskSplitAdapter<List<Object>, Integer> {
         /** {@inheritDoc} */
         @Override protected Collection<? extends ComputeJob> split(int gridSize, List<Object> list)
-            throws GridException {
+            throws IgniteCheckedException {
             Collection<ComputeJobAdapter> jobs = new ArrayList<>();
 
             if (list != null)
@@ -1495,7 +1495,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             int sum = 0;
 
             for (ComputeJobResult res : results)
@@ -1513,7 +1513,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
 
         /** {@inheritDoc} */
         @SuppressWarnings("unchecked")
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws IgniteCheckedException {
             if (arg.endsWith("intercepted"))
                 arg = arg.substring(0, arg.length() - 11);
 
@@ -1525,7 +1525,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return delegate.reduce(results);
         }
     }
@@ -1538,7 +1538,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
 
         /** {@inheritDoc} */
         @SuppressWarnings("unchecked")
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws IgniteCheckedException {
             JSON json = JSONSerializer.toJSON(arg);
 
             List list = json.isArray() ? JSONArray.toList((JSONArray)json, String.class, new JsonConfig()) : null;
@@ -1547,7 +1547,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return delegate.reduce(results);
         }
     }
@@ -1561,7 +1561,7 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
 
         /** {@inheritDoc} */
         @Override public void loadCache(IgniteBiInClosure<Object, Object> clo, Object... args)
-            throws GridException {
+            throws IgniteCheckedException {
             for (Map.Entry e : map.entrySet()) {
                 clo.apply(e.getKey(), e.getValue());
             }
@@ -1569,19 +1569,19 @@ public abstract class GridClientAbstractSelfTest extends GridCommonAbstractTest
 
         /** {@inheritDoc} */
         @Override public Object load(@Nullable GridCacheTx tx, Object key)
-            throws GridException {
+            throws IgniteCheckedException {
             return map.get(key);
         }
 
         /** {@inheritDoc} */
         @Override public void put(@Nullable GridCacheTx tx, Object key,
-            @Nullable Object val) throws GridException {
+            @Nullable Object val) throws IgniteCheckedException {
             map.put(key, val);
         }
 
         /** {@inheritDoc} */
         @Override public void remove(@Nullable GridCacheTx tx, Object key)
-            throws GridException {
+            throws IgniteCheckedException {
             map.remove(key);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/client/integration/GridClientPreferDirectSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/client/integration/GridClientPreferDirectSelfTest.java b/modules/clients/src/test/java/org/gridgain/client/integration/GridClientPreferDirectSelfTest.java
index b0d3a01..69b522d 100644
--- a/modules/clients/src/test/java/org/gridgain/client/integration/GridClientPreferDirectSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/client/integration/GridClientPreferDirectSelfTest.java
@@ -145,7 +145,7 @@ public class GridClientPreferDirectSelfTest extends GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg)
-            throws GridException {
+            throws IgniteCheckedException {
             Collection<ComputeJobAdapter> jobs = new ArrayList<>(gridSize);
 
             this.gridSize = gridSize;
@@ -169,7 +169,7 @@ public class GridClientPreferDirectSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public String reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public String reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             int sum = 0;
 
             for (ComputeJobResult res : results) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/client/router/GridClientFailedInitSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/client/router/GridTcpSslRouterSelfTest.java b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpSslRouterSelfTest.java
index 146b755..c1225a8 100644
--- a/modules/clients/src/test/java/org/gridgain/client/router/GridTcpSslRouterSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpSslRouterSelfTest.java
@@ -1,5 +1,6 @@
 package org.gridgain.client.router;
 
+import org.apache.ignite.*;
 import org.gridgain.client.ssl.*;
 import org.gridgain.grid.*;
 import org.gridgain.testframework.*;
@@ -21,7 +22,7 @@ public class GridTcpSslRouterSelfTest extends GridTcpRouterAbstractSelfTest {
     /**
      * @return Router configuration.
      */
-    @Override public GridTcpRouterConfiguration routerConfiguration() throws GridException {
+    @Override public GridTcpRouterConfiguration routerConfiguration() throws IgniteCheckedException {
         GridTcpRouterConfiguration cfg = super.routerConfiguration();
 
         cfg.setSslContextFactory(sslContextFactory());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
index 1d82286..b188671 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
@@ -147,7 +147,7 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
                     return null;
                 }
             },
-            GridException.class,
+            IgniteCheckedException.class,
             null
         );
 
@@ -328,7 +328,7 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
     /** */
     private static class SimpleTask extends ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             return Collections.singleton(new ComputeJobAdapter() {
                 @Nullable @Override public Object execute() {
                     return null;
@@ -337,7 +337,7 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }
@@ -345,7 +345,7 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
     /** */
     private static class FailedTask extends ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             return Collections.singleton(new ComputeJobAdapter() {
                 @Nullable @Override public Object execute() {
                     return null;
@@ -354,15 +354,15 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
-            throw new GridException("Task failed.");
+        @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
+            throw new IgniteCheckedException("Task failed.");
         }
     }
 
     /** */
     private static class TimedOutTask extends ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             return Collections.singleton(new ComputeJobAdapter() {
                 @Nullable @Override public Object execute() {
                     try {
@@ -378,7 +378,7 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestBinaryProtocolSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTaskCommandHandlerSelfTest.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTaskCommandHandlerSelfTest.java
index ec824ca..be26445 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTaskCommandHandlerSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTaskCommandHandlerSelfTest.java
@@ -176,7 +176,7 @@ public class GridTaskCommandHandlerSelfTest extends GridCommonAbstractTest {
      */
     private static class TestTask extends ComputeTaskSplitAdapter<String, Integer> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, final String arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, final String arg) throws IgniteCheckedException {
             return Collections.singletonList(new ComputeJobAdapter() {
                 @Override public Object execute() {
                     try {
@@ -192,7 +192,7 @@ public class GridTaskCommandHandlerSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             int sum = 0;
 
             for (ComputeJobResult res : results)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestBinaryClient.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask1.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask1.java
index 48785de..b82984c 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask1.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask1.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.rest;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
 
@@ -21,7 +21,7 @@ import java.util.*;
  */
 class TestTask1 extends ComputeTaskSplitAdapter<String, String> {
     /** {@inheritDoc} */
-    @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws GridException {
+    @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws IgniteCheckedException {
         Collection<ComputeJob> jobs = new ArrayList<>(gridSize);
 
         for (int i = 0; i < gridSize; i++)
@@ -38,7 +38,7 @@ class TestTask1 extends ComputeTaskSplitAdapter<String, String> {
     }
 
     /** {@inheritDoc} */
-    @Override public String reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public String reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return null;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask2.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask2.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask2.java
index 24173d3..aa1f57b 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask2.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask2.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.rest;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
 
@@ -23,7 +23,7 @@ class TestTask2 extends ComputeTaskSplitAdapter<String, String> {
     static final String RES = "Task 2 result.";
 
     /** {@inheritDoc} */
-    @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws GridException {
+    @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws IgniteCheckedException {
         Collection<ComputeJob> jobs = new ArrayList<>(gridSize);
 
         for (int i = 0; i < gridSize; i++)
@@ -40,7 +40,7 @@ class TestTask2 extends ComputeTaskSplitAdapter<String, String> {
     }
 
     /** {@inheritDoc} */
-    @Override public String reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public String reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return RES;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/loadtests/client/GridClientCacheBenchmark.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/loadtests/client/GridClientCacheBenchmark.java b/modules/clients/src/test/java/org/gridgain/loadtests/client/GridClientCacheBenchmark.java
index 25773cc..42118c3 100644
--- a/modules/clients/src/test/java/org/gridgain/loadtests/client/GridClientCacheBenchmark.java
+++ b/modules/clients/src/test/java/org/gridgain/loadtests/client/GridClientCacheBenchmark.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.loadtests.client;
 
+import org.apache.ignite.*;
 import org.gridgain.client.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.*;
@@ -189,7 +189,7 @@ public class GridClientCacheBenchmark {
      * @param args Command-line arguments.
      * @throws GridClientException If failed.
      */
-    public static void main(String[] args) throws GridClientException, GridException {
+    public static void main(String[] args) throws GridClientException, IgniteCheckedException {
         GridFileLock fileLock = GridLoadTestUtils.fileLock();
 
         fileLock.lock();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/Ignite.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteCheckedException.java b/modules/core/src/main/java/org/apache/ignite/IgniteCheckedException.java
new file mode 100644
index 0000000..55623bb
--- /dev/null
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteCheckedException.java
@@ -0,0 +1,108 @@
+/* @java.file.header */
+
+/*  _________        _____ __________________        _____
+ *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
+ *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
+ *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
+ *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ */
+
+package org.apache.ignite;
+
+import org.gridgain.grid.util.typedef.*;
+import org.jetbrains.annotations.*;
+
+import static org.gridgain.grid.util.GridUtils.*;
+
+/**
+ * General grid exception. This exception is used to indicate any error condition
+ * within Grid.
+ */
+public class IgniteCheckedException extends Exception {
+    /** */
+    private static final long serialVersionUID = 0L;
+
+    /**
+     * Create empty exception.
+     */
+    public IgniteCheckedException() {
+        // No-op.  +7(960)249-38-88
+    }
+
+    /**
+     * Creates new exception with given error message.
+     *
+     * @param msg Error message.
+     */
+    public IgniteCheckedException(String msg) {
+        super(msg);
+    }
+
+    /**
+     * Creates new grid exception with given throwable as a cause and
+     * source of error message.
+     *
+     * @param cause Non-null throwable cause.
+     */
+    public IgniteCheckedException(Throwable cause) {
+        this(cause.getMessage(), cause);
+    }
+
+    /**
+     * Creates new exception with given error message and optional nested exception.
+     *
+     * @param msg Error message.
+     * @param cause Optional nested exception (can be {@code null}).
+     */
+    public IgniteCheckedException(String msg, @Nullable Throwable cause) {
+        super(msg, cause);
+    }
+
+    /**
+     * Checks if this exception has given class in {@code 'cause'} hierarchy.
+     *
+     * @param cls Cause classes to check (if {@code null} or empty, {@code false} is returned).
+     * @return {@code True} if one of the causing exception is an instance of passed in classes,
+     *      {@code false} otherwise.
+     */
+    public boolean hasCause(@Nullable Class<? extends Throwable>... cls) {
+        return X.hasCause(this, cls);
+    }
+
+    /**
+     * Gets first exception of given class from {@code 'cause'} hierarchy if any.
+     *
+     * @param cls Cause class to get cause (if {@code null}, {@code null} is returned).
+     * @return First causing exception of passed in class, {@code null} otherwise.
+     */
+    @Nullable public <T extends Throwable> T getCause(@Nullable Class<T> cls) {
+        return X.cause(this, cls);
+    }
+
+    /**
+     * {@inheritDoc}
+     * <p>
+     * Adds troubleshooting links if they where not added by below in {@code cause} hierarchy.
+     */
+    @Override public String getMessage() {
+        return X.hasCauseExcludeRoot(this, IgniteCheckedException.class, IgniteException.class) ?
+            super.getMessage() : errorMessageWithHelpUrls(super.getMessage());
+    }
+
+    /**
+     * Returns exception message.
+     * <p>
+     * Unlike {@link #getMessage()} this method never include troubleshooting links
+     * to the result string.
+     *
+     * @return Original message.
+     */
+    public String getOriginalMessage() {
+        return super.getMessage();
+    }
+
+    /** {@inheritDoc} */
+    @Override public String toString() {
+        return getClass() + ": " + getMessage();
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/client/router/GridClientFailedInitSelfTest.java b/modules/clients/src/test/java/org/gridgain/client/router/GridClientFailedInitSelfTest.java
index 50a6406..03efbb2 100644
--- a/modules/clients/src/test/java/org/gridgain/client/router/GridClientFailedInitSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/client/router/GridClientFailedInitSelfTest.java
@@ -212,9 +212,9 @@ public class GridClientFailedInitSelfTest extends GridCommonAbstractTest {
 
     /**
      * Starts router.
      * @throws GridException If failed.
      */
-    private void startRouters() throws GridException {
+    private void startRouters() throws IgniteCheckedException {
         GridTcpRouterConfiguration tcpCfg = new GridTcpRouterConfiguration();
 
         tcpCfg.setHost(HOST);
@@ -250,7 +250,7 @@ public class GridClientFailedInitSelfTest extends GridCommonAbstractTest {
      */
     private static class TestTask extends ComputeTaskSplitAdapter<String, String> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, final String arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, final String arg) throws IgniteCheckedException {
             return Collections.singleton(new ComputeJobAdapter() {
                 @Override public String execute() {
                     return arg;
@@ -259,7 +259,7 @@ public class GridClientFailedInitSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public String reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public String reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assertEquals(1, results.size());
 
             return results.get(0).getData();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterAbstractSelfTest.java
----------------------------------------------------------------------
@@ -212,9 +212,9 @@ public class GridClientFailedInitSelfTest extends GridCommonAbstractTest {
     /**
      * Starts router.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterAbstractSelfTest.java b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterAbstractSelfTest.java
index ae8784e..a47ad33 100644
--- a/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterAbstractSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterAbstractSelfTest.java
@@ -9,11 +9,11 @@
 
 package org.gridgain.client.router;
 
+import org.apache.ignite.*;
 import org.apache.ignite.logger.log4j.*;
 import org.gridgain.client.*;
 import org.gridgain.client.integration.*;
 import org.gridgain.client.router.impl.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 
 import java.util.*;
@@ -90,9 +90,9 @@ public abstract class GridTcpRouterAbstractSelfTest extends GridClientAbstractSe
 
     /**
      * @return Router configuration.
      * @throws GridException If failed.
      */
-    public GridTcpRouterConfiguration routerConfiguration() throws GridException {
+    public GridTcpRouterConfiguration routerConfiguration() throws IgniteCheckedException {
         GridTcpRouterConfiguration cfg = new GridTcpRouterConfiguration();
 
         cfg.setHost(HOST);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterMultiNodeSelfTest.java
----------------------------------------------------------------------
@@ -90,9 +90,9 @@ public abstract class GridTcpRouterAbstractSelfTest extends GridClientAbstractSe
     /**
      * @return Router configuration.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterMultiNodeSelfTest.java b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterMultiNodeSelfTest.java
index 0fc4764..93b5d7e 100644
--- a/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterMultiNodeSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpRouterMultiNodeSelfTest.java
@@ -1,10 +1,10 @@
 package org.gridgain.client.router;
 
+import org.apache.ignite.*;
 import org.apache.ignite.logger.log4j.*;
 import org.gridgain.client.*;
 import org.gridgain.client.integration.*;
 import org.gridgain.client.router.impl.*;
-import org.gridgain.grid.*;
 
 import java.util.*;
 
@@ -61,9 +61,9 @@ public class GridTcpRouterMultiNodeSelfTest extends GridClientAbstractMultiNodeS
     /**
      * @param i Number of router. Used to avoid configuration conflicts.
      * @return Router configuration.
      * @throws GridException If failed.
      */
-    private GridTcpRouterConfiguration routerConfiguration(int i) throws GridException {
+    private GridTcpRouterConfiguration routerConfiguration(int i) throws IgniteCheckedException {
         GridTcpRouterConfiguration cfg = new GridTcpRouterConfiguration();
 
         cfg.setHost(HOST);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/client/router/GridTcpSslRouterSelfTest.java
----------------------------------------------------------------------
@@ -61,9 +61,9 @@ public class GridTcpRouterMultiNodeSelfTest extends GridClientAbstractMultiNodeS
      * @param i Number of router. Used to avoid configuration conflicts.
      * @return Router configuration.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestBinaryProtocolSelfTest.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestBinaryProtocolSelfTest.java
index 8f99de5..e6439e8 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestBinaryProtocolSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestBinaryProtocolSelfTest.java
@@ -9,15 +9,15 @@
 
 package org.gridgain.grid.kernal.processors.rest;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
-import org.gridgain.grid.*;
-import org.gridgain.grid.cache.*;
-import org.gridgain.grid.kernal.*;
-import org.gridgain.grid.kernal.processors.rest.client.message.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
+import org.gridgain.grid.cache.*;
+import org.gridgain.grid.kernal.*;
+import org.gridgain.grid.kernal.processors.rest.client.message.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.*;
@@ -117,9 +117,9 @@ public class GridRestBinaryProtocolSelfTest extends GridCommonAbstractTest {
 
     /**
      * @return Client.
      * @throws GridException In case of error.
      */
-    private GridTestBinaryClient client() throws GridException {
+    private GridTestBinaryClient client() throws IgniteCheckedException {
         return new GridTestBinaryClient(HOST, PORT);
     }
 
@@ -195,7 +195,7 @@ public class GridRestBinaryProtocolSelfTest extends GridCommonAbstractTest {
                         return client.cacheGet(null, "key");
                     }
                 },
-                GridException.class,
+                IgniteCheckedException.class,
                 "Failed to process client request: Failed to find registered handler for command: CACHE_GET");
         }
         finally {
@@ -579,7 +579,7 @@ public class GridRestBinaryProtocolSelfTest extends GridCommonAbstractTest {
                     return null;
                 }
             },
-            GridException.class,
+            IgniteCheckedException.class,
             null
         );
     }
@@ -590,7 +590,7 @@ public class GridRestBinaryProtocolSelfTest extends GridCommonAbstractTest {
     private static class TestTask extends ComputeTaskSplitAdapter<List<Object>, Integer> {
         /** {@inheritDoc} */
         @Override protected Collection<? extends ComputeJob> split(int gridSize, List<Object> args)
-            throws GridException {
+            throws IgniteCheckedException {
             Collection<ComputeJobAdapter> jobs = new ArrayList<>(args.size());
 
             for (final Object arg : args) {
@@ -613,7 +613,7 @@ public class GridRestBinaryProtocolSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             int sum = 0;
 
             for (ComputeJobResult res : results)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestMemcacheProtocolSelfTest.java
----------------------------------------------------------------------
@@ -117,9 +117,9 @@ public class GridRestBinaryProtocolSelfTest extends GridCommonAbstractTest {
     /**
      * @return Client.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestMemcacheProtocolSelfTest.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestMemcacheProtocolSelfTest.java
index dee3175..9682c1f 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestMemcacheProtocolSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestMemcacheProtocolSelfTest.java
@@ -10,6 +10,7 @@
 package org.gridgain.grid.kernal.processors.rest;
 
 import junit.framework.*;
+import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
@@ -109,9 +110,9 @@ public class GridRestMemcacheProtocolSelfTest extends GridCommonAbstractTest {
 
     /**
      * @return Client.
      * @throws GridException In case of error.
      */
-    private GridTestMemcacheClient client() throws GridException {
+    private GridTestMemcacheClient client() throws IgniteCheckedException {
         return new GridTestMemcacheClient(HOST, PORT);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorTest.java
----------------------------------------------------------------------
@@ -109,9 +110,9 @@ public class GridRestMemcacheProtocolSelfTest extends GridCommonAbstractTest {
     /**
      * @return Client.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorTest.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorTest.java
index dc2af51..0b65341 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorTest.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorTest.java
@@ -9,11 +9,11 @@
 
 package org.gridgain.grid.kernal.processors.rest;
 
+import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
-import org.gridgain.grid.*;
-import org.gridgain.grid.cache.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
+import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.junits.common.*;
@@ -124,9 +124,9 @@ public class GridRestProcessorTest extends GridCommonAbstractTest {
     }
 
     /**
      * @throws GridException If failed.
      */
-    private void populateCache() throws GridException {
+    private void populateCache() throws IgniteCheckedException {
         GridCache<String, Object> cache = G.ignite().cache(null);
 
         cache.put("int", intValue());
@@ -144,9 +144,9 @@ public class GridRestProcessorTest extends GridCommonAbstractTest {
     }
 
     /**
      * @throws GridException If failed.
      */
-    private void deployTasks() throws GridException {
+    private void deployTasks() throws IgniteCheckedException {
         G.ignite().compute().localDeployTask(TestTask1.class, TestTask1.class.getClassLoader());
         G.ignite().compute().localDeployTask(TestTask2.class, TestTask2.class.getClassLoader());
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTaskCommandHandlerSelfTest.java
----------------------------------------------------------------------
@@ -124,9 +124,9 @@ public class GridRestProcessorTest extends GridCommonAbstractTest {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -144,9 +144,9 @@ public class GridRestProcessorTest extends GridCommonAbstractTest {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestBinaryClient.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestBinaryClient.java
index d2adfc0..d6034df 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestBinaryClient.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestBinaryClient.java
@@ -65,9 +65,9 @@ final class GridTestBinaryClient {
      *
      * @param host Hostname.
      * @param port Port number.
      * @throws GridException In case of error.
      */
-    GridTestBinaryClient(String host, int port) throws GridException {
+    GridTestBinaryClient(String host, int port) throws IgniteCheckedException {
         assert host != null;
         assert port > 0;
 
@@ -95,7 +95,7 @@ final class GridTestBinaryClient {
                 "Client handshake failed [code=" + buf[0] + ']';
         }
         catch (IOException e) {
-            throw new GridException("Failed to establish connection.", e);
+            throw new IgniteCheckedException("Failed to establish connection.", e);
         }
 
         // Start socket reader thread.
@@ -193,7 +193,7 @@ final class GridTestBinaryClient {
     }
 
     /** {@inheritDoc} */
-    public void shutdown() throws GridException {
+    public void shutdown() throws IgniteCheckedException {
         try {
             if (rdr != null) {
                 rdr.interrupt();
@@ -204,7 +204,7 @@ final class GridTestBinaryClient {
             }
         }
         catch (InterruptedException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 
@@ -213,9 +213,9 @@ final class GridTestBinaryClient {
      *
      * @param msg Message to request,
      * @return Response object.
      * @throws GridException If request failed.
      */
-    private Response makeRequest(GridClientMessage msg) throws GridException {
+    private Response makeRequest(GridClientMessage msg) throws IgniteCheckedException {
         assert msg != null;
 
         // Send request
@@ -223,7 +223,7 @@ final class GridTestBinaryClient {
             sock.getOutputStream().write(createPacket(msg));
         }
         catch (IOException e) {
-            throw new GridException("Failed to send packet.", e);
+            throw new IgniteCheckedException("Failed to send packet.", e);
         }
 
         // Wait for response.
@@ -238,7 +238,7 @@ final class GridTestBinaryClient {
                 // Check opaque value.
                 if (res.opaque() == msg.requestId()) {
                     if (!res.isSuccess() && res.error() != null)
-                        throw new GridException(res.error());
+                        throw new IgniteCheckedException(res.error());
                     else
                         return res;
                 }
@@ -247,7 +247,7 @@ final class GridTestBinaryClient {
                     queue.add(res);
             }
             catch (InterruptedException e) {
-                throw new GridException("Interrupted while waiting for response.", e);
+                throw new IgniteCheckedException("Interrupted while waiting for response.", e);
             }
         }
 
@@ -285,10 +285,10 @@ final class GridTestBinaryClient {
      * @param key Key.
      * @param val Value.
      * @return If value was actually put.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cachePut(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         return cachePutAll(cacheName, Collections.singletonMap(key, val));
     }
 
@@ -297,10 +297,10 @@ final class GridTestBinaryClient {
      * @param entries Entries.
      * @return {@code True} if map contained more then one entry or if put succeeded in case of one entry,
      *      {@code false} otherwise
      * @throws GridException In case of error.
      */
     public <K, V> boolean cachePutAll(@Nullable String cacheName, Map<K, V> entries)
-        throws GridException {
+        throws IgniteCheckedException {
         assert entries != null;
 
         GridClientCacheRequest req = new GridClientCacheRequest(PUT_ALL);
@@ -316,10 +316,10 @@ final class GridTestBinaryClient {
      * @param cacheName Cache name.
      * @param key Key.
      * @return Value.
      * @throws GridException In case of error.
      */
     public <K, V> V cacheGet(@Nullable String cacheName, K key)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
 
         GridClientCacheRequest req = new GridClientCacheRequest(GET);
@@ -336,10 +336,10 @@ final class GridTestBinaryClient {
      * @param cacheName Cache name.
      * @param keys Keys.
      * @return Entries.
      * @throws GridException In case of error.
      */
     public <K, V> Map<K, V> cacheGetAll(@Nullable String cacheName, K... keys)
-        throws GridException {
+        throws IgniteCheckedException {
         assert keys != null;
 
         GridClientCacheRequest req = new GridClientCacheRequest(GET_ALL);
@@ -355,10 +355,10 @@ final class GridTestBinaryClient {
      * @param cacheName Cache name.
      * @param key Key.
      * @return Whether entry was actually removed.
      * @throws GridException In case of error.
      */
     @SuppressWarnings("unchecked")
-    public <K> boolean cacheRemove(@Nullable String cacheName, K key) throws GridException {
+    public <K> boolean cacheRemove(@Nullable String cacheName, K key) throws IgniteCheckedException {
         assert key != null;
 
         GridClientCacheRequest req = new GridClientCacheRequest(RMV);
@@ -374,10 +374,10 @@ final class GridTestBinaryClient {
      * @param cacheName Cache name.
      * @param keys Keys.
      * @return Whether entries were actually removed
      * @throws GridException In case of error.
      */
     public <K> boolean cacheRemoveAll(@Nullable String cacheName, K... keys)
-        throws GridException {
+        throws IgniteCheckedException {
         assert keys != null;
 
         GridClientCacheRequest req = new GridClientCacheRequest(RMV_ALL);
@@ -394,10 +394,10 @@ final class GridTestBinaryClient {
      * @param key Key.
      * @param val Value.
      * @return Whether value was actually replaced.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cacheReplace(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -417,10 +417,10 @@ final class GridTestBinaryClient {
      * @param val1 Value 1.
      * @param val2 Value 2.
      * @return Whether new value was actually set.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cacheCompareAndSet(@Nullable String cacheName, K key, @Nullable V val1, @Nullable V val2)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
 
         GridClientCacheRequest msg = new GridClientCacheRequest(CAS);
@@ -437,9 +437,9 @@ final class GridTestBinaryClient {
     /**
      * @param cacheName Cache name.
      * @return Metrics.
      * @throws GridException In case of error.
      */
-    public <K> Map<String, Long> cacheMetrics(@Nullable String cacheName) throws GridException {
+    public <K> Map<String, Long> cacheMetrics(@Nullable String cacheName) throws IgniteCheckedException {
         GridClientCacheRequest metrics = new GridClientCacheRequest(METRICS);
 
         metrics.requestId(idCntr.getAndIncrement());
@@ -453,10 +453,10 @@ final class GridTestBinaryClient {
      * @param key Key.
      * @param val Value.
      * @return Whether entry was appended.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cacheAppend(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -475,10 +475,10 @@ final class GridTestBinaryClient {
      * @param key Key.
      * @param val Value.
      * @return Whether entry was prepended.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cachePrepend(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -496,9 +496,9 @@ final class GridTestBinaryClient {
      * @param taskName Task name.
      * @param arg Task arguments.
      * @return Task execution result.
      * @throws GridException In case of error.
      */
-    public GridClientTaskResultBean execute(String taskName, @Nullable Object arg) throws GridException {
+    public GridClientTaskResultBean execute(String taskName, @Nullable Object arg) throws IgniteCheckedException {
         assert !F.isEmpty(taskName);
 
         GridClientTaskRequest msg = new GridClientTaskRequest();
@@ -514,10 +514,10 @@ final class GridTestBinaryClient {
      * @param includeAttrs Whether to include attributes.
      * @param includeMetrics Whether to include metrics.
      * @return Node.
      * @throws GridException In case of error.
      */
     public GridClientNodeBean node(UUID id, boolean includeAttrs, boolean includeMetrics)
-        throws GridException {
+        throws IgniteCheckedException {
         assert id != null;
 
         GridClientTopologyRequest msg = new GridClientTopologyRequest();
@@ -534,10 +534,10 @@ final class GridTestBinaryClient {
      * @param includeAttrs Whether to include attributes.
      * @param includeMetrics Whether to include metrics.
      * @return Node.
      * @throws GridException In case of error.
      */
     public GridClientNodeBean node(String ipAddr, boolean includeAttrs, boolean includeMetrics)
-        throws GridException {
+        throws IgniteCheckedException {
         assert !F.isEmpty(ipAddr);
 
         GridClientTopologyRequest msg = new GridClientTopologyRequest();
@@ -553,10 +553,10 @@ final class GridTestBinaryClient {
      * @param includeAttrs Whether to include attributes.
      * @param includeMetrics Whether to include metrics.
      * @return Nodes.
      * @throws GridException In case of error.
      */
     public List<GridClientNodeBean> topology(boolean includeAttrs, boolean includeMetrics)
-        throws GridException {
+        throws IgniteCheckedException {
         GridClientTopologyRequest msg = new GridClientTopologyRequest();
 
         msg.includeAttributes(includeAttrs);
@@ -568,9 +568,9 @@ final class GridTestBinaryClient {
     /**
      * @param path Log file path.
      * @return Log file contents.
      * @throws GridException In case of error.
      */
-    public List<String> log(@Nullable String path, int from, int to) throws GridException {
+    public List<String> log(@Nullable String path, int from, int to) throws IgniteCheckedException {
         GridClientLogRequest msg = new GridClientLogRequest();
 
         msg.requestId(idCntr.getAndIncrement());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestMemcacheClient.java
----------------------------------------------------------------------
@@ -65,9 +65,9 @@ final class GridTestBinaryClient {
      * @param host Hostname.
      * @param port Port number.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -213,9 +213,9 @@ final class GridTestBinaryClient {
      * @param msg Message to request,
      * @return Response object.
-     * @throws GridException If request failed.
+     * @throws IgniteCheckedException If request failed.
      */
@@ -285,10 +285,10 @@ final class GridTestBinaryClient {
      * @param val Value.
      * @return If value was actually put.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cachePut(@Nullable String cacheName, K key, V val)
@@ -297,10 +297,10 @@ final class GridTestBinaryClient {
      * @return {@code True} if map contained more then one entry or if put succeeded in case of one entry,
      *      {@code false} otherwise
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cachePutAll(@Nullable String cacheName, Map<K, V> entries)
@@ -316,10 +316,10 @@ final class GridTestBinaryClient {
      * @param key Key.
      * @return Value.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> V cacheGet(@Nullable String cacheName, K key)
@@ -336,10 +336,10 @@ final class GridTestBinaryClient {
      * @param keys Keys.
      * @return Entries.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> Map<K, V> cacheGetAll(@Nullable String cacheName, K... keys)
@@ -355,10 +355,10 @@ final class GridTestBinaryClient {
      * @param key Key.
      * @return Whether entry was actually removed.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     @SuppressWarnings("unchecked")
@@ -374,10 +374,10 @@ final class GridTestBinaryClient {
      * @param keys Keys.
      * @return Whether entries were actually removed
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K> boolean cacheRemoveAll(@Nullable String cacheName, K... keys)
@@ -394,10 +394,10 @@ final class GridTestBinaryClient {
      * @param val Value.
      * @return Whether value was actually replaced.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cacheReplace(@Nullable String cacheName, K key, V val)
@@ -417,10 +417,10 @@ final class GridTestBinaryClient {
      * @param val2 Value 2.
      * @return Whether new value was actually set.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cacheCompareAndSet(@Nullable String cacheName, K key, @Nullable V val1, @Nullable V val2)
@@ -437,9 +437,9 @@ final class GridTestBinaryClient {
      * @param cacheName Cache name.
      * @return Metrics.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -453,10 +453,10 @@ final class GridTestBinaryClient {
      * @param val Value.
      * @return Whether entry was appended.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cacheAppend(@Nullable String cacheName, K key, V val)
@@ -475,10 +475,10 @@ final class GridTestBinaryClient {
      * @param val Value.
      * @return Whether entry was prepended.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cachePrepend(@Nullable String cacheName, K key, V val)
@@ -496,9 +496,9 @@ final class GridTestBinaryClient {
      * @param arg Task arguments.
      * @return Task execution result.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -514,10 +514,10 @@ final class GridTestBinaryClient {
      * @param includeMetrics Whether to include metrics.
      * @return Node.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public GridClientNodeBean node(UUID id, boolean includeAttrs, boolean includeMetrics)
@@ -534,10 +534,10 @@ final class GridTestBinaryClient {
      * @param includeMetrics Whether to include metrics.
      * @return Node.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public GridClientNodeBean node(String ipAddr, boolean includeAttrs, boolean includeMetrics)
@@ -553,10 +553,10 @@ final class GridTestBinaryClient {
      * @param includeMetrics Whether to include metrics.
      * @return Nodes.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public List<GridClientNodeBean> topology(boolean includeAttrs, boolean includeMetrics)
@@ -568,9 +568,9 @@ final class GridTestBinaryClient {
      * @param path Log file path.
      * @return Log file contents.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestMemcacheClient.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestMemcacheClient.java
index 9292b88..aa1fa3d 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestMemcacheClient.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridTestMemcacheClient.java
@@ -84,9 +84,9 @@ final class GridTestMemcacheClient {
      *
      * @param host Hostname.
      * @param port Port number.
      * @throws GridException In case of error.
      */
-    GridTestMemcacheClient(String host, int port) throws GridException {
+    GridTestMemcacheClient(String host, int port) throws IgniteCheckedException {
         assert host != null;
         assert port > 0;
 
@@ -94,7 +94,7 @@ final class GridTestMemcacheClient {
             sock = new Socket(host, port);
         }
         catch (IOException e) {
-            throw new GridException("Failed to establish connection.", e);
+            throw new IgniteCheckedException("Failed to establish connection.", e);
         }
 
         // Start socket reader thread.
@@ -236,7 +236,7 @@ final class GridTestMemcacheClient {
     }
 
     /** {@inheritDoc} */
-    public void shutdown() throws GridException {
+    public void shutdown() throws IgniteCheckedException {
         try {
             if (rdr != null) {
                 rdr.interrupt();
@@ -247,7 +247,7 @@ final class GridTestMemcacheClient {
             }
         }
         catch (InterruptedException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 
@@ -260,7 +260,7 @@ final class GridTestMemcacheClient {
      * @param val Value.
      * @param extras Extras.
      * @return Response.
      * @throws GridException In case of error.
      */
     private Response makeRequest(
         Command cmd,
@@ -268,7 +268,7 @@ final class GridTestMemcacheClient {
         @Nullable Object key,
         @Nullable Object val,
         @Nullable Long... extras
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         assert cmd != null;
 
         int opaque = opaqueCntr.getAndIncrement();
@@ -278,7 +278,7 @@ final class GridTestMemcacheClient {
             sock.getOutputStream().write(createPacket(cmd, cacheName, key, val, opaque, extras));
         }
         catch (IOException e) {
-            throw new GridException("Failed to send packet.", e);
+            throw new IgniteCheckedException("Failed to send packet.", e);
         }
 
         // Wait for response.
@@ -293,7 +293,7 @@ final class GridTestMemcacheClient {
                 // Check opaque value.
                 if (res.getOpaque() == opaque) {
                     if (!res.isSuccess() && res.getObject() != null)
-                        throw new GridException((String)res.getObject());
+                        throw new IgniteCheckedException((String)res.getObject());
                     else
                         return res;
                 }
@@ -302,7 +302,7 @@ final class GridTestMemcacheClient {
                     queue.add(res);
             }
             catch (InterruptedException e) {
-                throw new GridException("Interrupted while waiting for response.", e);
+                throw new IgniteCheckedException("Interrupted while waiting for response.", e);
             }
         }
     }
@@ -316,7 +316,7 @@ final class GridTestMemcacheClient {
      * @param val Value.
      * @param extras Extras.
      * @return Response.
      * @throws GridException In case of error.
      */
     private List<Response> makeMultiRequest(
         Command cmd,
@@ -324,7 +324,7 @@ final class GridTestMemcacheClient {
         @Nullable Object key,
         @Nullable Object val,
         @Nullable Long... extras
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         assert cmd != null;
 
         int opaque = opaqueCntr.getAndIncrement();
@@ -336,7 +336,7 @@ final class GridTestMemcacheClient {
             sock.getOutputStream().write(createPacket(cmd, cacheName, key, val, opaque, extras));
         }
         catch (IOException e) {
-            throw new GridException("Failed to send packet.", e);
+            throw new IgniteCheckedException("Failed to send packet.", e);
         }
 
         // Wait for response.
@@ -351,7 +351,7 @@ final class GridTestMemcacheClient {
                 // Check opaque value.
                 if (res.getOpaque() == opaque) {
                     if (!res.isSuccess() && res.getObject() != null)
-                        throw new GridException((String)res.getObject());
+                        throw new IgniteCheckedException((String)res.getObject());
                     else {
                         if (res.getObject() == null)
                             return resList;
@@ -364,7 +364,7 @@ final class GridTestMemcacheClient {
                     queue.add(res);
             }
             catch (InterruptedException e) {
-                throw new GridException("Interrupted while waiting for response.", e);
+                throw new IgniteCheckedException("Interrupted while waiting for response.", e);
             }
         }
     }
@@ -378,7 +378,7 @@ final class GridTestMemcacheClient {
      * @param val Value.
      * @param opaque Opaque.
      * @param extras Extras.
      * @throws GridException In case of error.
      * @return Packet.
      */
     private byte[] createPacket(
@@ -388,7 +388,7 @@ final class GridTestMemcacheClient {
         @Nullable Object val,
         int opaque,
         @Nullable Long[] extras
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         assert cmd != null;
         assert opaque >= 0;
 
@@ -447,10 +447,10 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @param val Value.
      * @return If value was actually put.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cachePut(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -461,10 +461,10 @@ final class GridTestMemcacheClient {
      * @param cacheName Cache name.
      * @param key Key.
      * @return Value.
      * @throws GridException In case of error.
      */
     public <K, V> V cacheGet(@Nullable String cacheName, K key)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
 
         return makeRequest(Command.GET, cacheName, key, null).getObject();
@@ -474,9 +474,9 @@ final class GridTestMemcacheClient {
      * @param cacheName Cache name.
      * @param key Key.
      * @return Whether entry was actually removed.
      * @throws GridException In case of error.
      */
-    public <K> boolean cacheRemove(@Nullable String cacheName, K key) throws GridException {
+    public <K> boolean cacheRemove(@Nullable String cacheName, K key) throws IgniteCheckedException {
         assert key != null;
 
         return makeRequest(Command.REMOVE, cacheName, key, null).isSuccess();
@@ -487,10 +487,10 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @param val Value.
      * @return Whether entry was added.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cacheAdd(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -502,10 +502,10 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @param val Value.
      * @return Whether value was actually replaced.
      * @throws GridException In case of error.
      */
     public <K, V> boolean cacheReplace(@Nullable String cacheName, K key, V val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -514,9 +514,9 @@ final class GridTestMemcacheClient {
 
     /**
      * @param cacheName Cache name.
      * @throws GridException In case of error.
      */
-    public <K> Map<String, Long> cacheMetrics(@Nullable String cacheName) throws GridException {
+    public <K> Map<String, Long> cacheMetrics(@Nullable String cacheName) throws IgniteCheckedException {
         List<Response> raw = makeMultiRequest(Command.CACHE_METRICS, cacheName, null, null);
 
         Map<String, Long> res = new HashMap<>(raw.size());
@@ -533,10 +533,10 @@ final class GridTestMemcacheClient {
      * @param init Initial value (optional).
      * @param incr Amount to add.
      * @return New value.
      * @throws GridException In case of error.
      */
     public <K> long cacheIncrement(@Nullable String cacheName, K key, @Nullable Long init, long incr)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
 
         return makeRequest(Command.INCREMENT, cacheName, key, null, incr, init).<Long>getObject();
@@ -548,10 +548,10 @@ final class GridTestMemcacheClient {
      * @param init Initial value (optional).
      * @param decr Amount to subtract.
      * @return New value.
      * @throws GridException In case of error.
      */
     public <K> long cacheDecrement(@Nullable String cacheName, K key, @Nullable Long init, long decr)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
 
         return makeRequest(Command.DECREMENT, cacheName, key, null, decr, init).<Long>getObject();
@@ -562,10 +562,10 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @param val Value to append.
      * @return Whether operation succeeded.
      * @throws GridException In case of error.
      */
     public <K> boolean cacheAppend(@Nullable String cacheName, K key, String val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -577,10 +577,10 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @param val Value to prepend.
      * @return Whether operation succeeded.
      * @throws GridException In case of error.
      */
     public <K> boolean cachePrepend(@Nullable String cacheName, K key, String val)
-        throws GridException {
+        throws IgniteCheckedException {
         assert key != null;
         assert val != null;
 
@@ -589,16 +589,16 @@ final class GridTestMemcacheClient {
 
     /**
      * @return Version.
      * @throws GridException In case of error.
      */
-    public String version() throws GridException {
+    public String version() throws IgniteCheckedException {
         return makeRequest(Command.VERSION, null, null, null).getObject();
     }
 
     /**
      * @throws GridException In case of error.
      */
-    public void noop() throws GridException {
+    public void noop() throws IgniteCheckedException {
         Response res = makeRequest(Command.NOOP, null, null, null);
 
         assert res != null;
@@ -607,9 +607,9 @@ final class GridTestMemcacheClient {
     }
 
     /**
      * @throws GridException In case of error.
      */
-    public void quit() throws GridException {
+    public void quit() throws IgniteCheckedException {
         makeRequest(Command.QUIT, null, null, null);
 
         assert sock.isClosed();
@@ -620,9 +620,9 @@ final class GridTestMemcacheClient {
      *
      * @param obj Object.
      * @return Encoded data.
      * @throws GridException In case of error.
      */
-    public Data encode(@Nullable Object obj) throws GridException {
+    public Data encode(@Nullable Object obj) throws IgniteCheckedException {
         if (obj == null)
             return new Data(null, (short)0);
 
@@ -684,9 +684,9 @@ final class GridTestMemcacheClient {
      * @param bytes Byte array to decode.
      * @param flags Flags.
      * @return Decoded value.
      * @throws GridException In case of error.
      */
-    public Object decode(byte[] bytes, short flags) throws GridException {
+    public Object decode(byte[] bytes, short flags) throws IgniteCheckedException {
         assert bytes != null;
         assert flags >= 0;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/TestTask1.java
----------------------------------------------------------------------
@@ -84,9 +84,9 @@ final class GridTestMemcacheClient {
      * @param host Hostname.
      * @param port Port number.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -260,7 +260,7 @@ final class GridTestMemcacheClient {
      * @param extras Extras.
      * @return Response.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private Response makeRequest(
@@ -316,7 +316,7 @@ final class GridTestMemcacheClient {
      * @param extras Extras.
      * @return Response.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private List<Response> makeMultiRequest(
@@ -378,7 +378,7 @@ final class GridTestMemcacheClient {
      * @param opaque Opaque.
      * @param extras Extras.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @return Packet.
      */
@@ -447,10 +447,10 @@ final class GridTestMemcacheClient {
      * @param val Value.
      * @return If value was actually put.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cachePut(@Nullable String cacheName, K key, V val)
@@ -461,10 +461,10 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @return Value.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> V cacheGet(@Nullable String cacheName, K key)
@@ -474,9 +474,9 @@ final class GridTestMemcacheClient {
      * @param key Key.
      * @return Whether entry was actually removed.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -487,10 +487,10 @@ final class GridTestMemcacheClient {
      * @param val Value.
      * @return Whether entry was added.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cacheAdd(@Nullable String cacheName, K key, V val)
@@ -502,10 +502,10 @@ final class GridTestMemcacheClient {
      * @param val Value.
      * @return Whether value was actually replaced.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K, V> boolean cacheReplace(@Nullable String cacheName, K key, V val)
@@ -514,9 +514,9 @@ final class GridTestMemcacheClient {
     /**
      * @param cacheName Cache name.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -533,10 +533,10 @@ final class GridTestMemcacheClient {
      * @param incr Amount to add.
      * @return New value.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K> long cacheIncrement(@Nullable String cacheName, K key, @Nullable Long init, long incr)
@@ -548,10 +548,10 @@ final class GridTestMemcacheClient {
      * @param decr Amount to subtract.
      * @return New value.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K> long cacheDecrement(@Nullable String cacheName, K key, @Nullable Long init, long decr)
@@ -562,10 +562,10 @@ final class GridTestMemcacheClient {
      * @param val Value to append.
      * @return Whether operation succeeded.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K> boolean cacheAppend(@Nullable String cacheName, K key, String val)
@@ -577,10 +577,10 @@ final class GridTestMemcacheClient {
      * @param val Value to prepend.
      * @return Whether operation succeeded.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public <K> boolean cachePrepend(@Nullable String cacheName, K key, String val)
@@ -589,16 +589,16 @@ final class GridTestMemcacheClient {
     /**
      * @return Version.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -589,16 +589,16 @@ final class GridTestMemcacheClient {
 
     /**
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -607,9 +607,9 @@ final class GridTestMemcacheClient {
 
     /**
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -620,9 +620,9 @@ final class GridTestMemcacheClient {
      * @param obj Object.
      * @return Encoded data.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -684,9 +684,9 @@ final class GridTestMemcacheClient {
      * @param flags Flags.
      * @return Decoded value.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/Ignite.java b/modules/core/src/main/java/org/apache/ignite/Ignite.java
index d53e8a3..fe033e7 100644
--- a/modules/core/src/main/java/org/apache/ignite/Ignite.java
+++ b/modules/core/src/main/java/org/apache/ignite/Ignite.java
@@ -309,7 +309,7 @@ public interface Ignite extends AutoCloseable {
      * The method is invoked automatically on objects managed by the
      * {@code try-with-resources} statement.
      *
      * @throws GridException If failed to stop grid.
      */
-    @Override public void close() throws GridException;
+    @Override public void close() throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/IgniteCheckedException.java
----------------------------------------------------------------------
@@ -309,7 +309,7 @@ public interface Ignite extends AutoCloseable {
      * {@code try-with-resources} statement.
      *
-     * @throws GridException If failed to stop grid.
+     * @throws IgniteCheckedException If failed to stop grid.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java b/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
index 93a7cfd..7b1a91d 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteCluster.java
@@ -111,10 +111,10 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @param cacheName Cache name, if {@code null}, then default cache instance is used.
      * @param keys Cache keys to map to nodes.
      * @return Map of nodes to cache keys or empty map if there are no alive nodes for this cache.
      * @throws GridException If failed to map cache keys.
      */
     public <K> Map<ClusterNode, Collection<K>> mapKeysToNodes(@Nullable String cacheName,
-        @Nullable Collection<? extends K> keys) throws GridException;
+        @Nullable Collection<? extends K> keys) throws IgniteCheckedException;
 
     /**
      * This method provides ability to detect which cache keys are mapped to which nodes
@@ -135,9 +135,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @param key Cache key to map to a node.
      * @return Primary node for the key or {@code null} if cache with given name
      *      is not present in the grid.
      * @throws GridException If failed to map key.
      */
-    @Nullable public <K> ClusterNode mapKeyToNode(@Nullable String cacheName, K key) throws GridException;
+    @Nullable public <K> ClusterNode mapKeyToNode(@Nullable String cacheName, K key) throws IgniteCheckedException;
 
     /**
      * Starts one or more nodes on remote host(s).
@@ -164,10 +164,10 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @param maxConn Number of parallel SSH connections to one host.
      * @return Collection of tuples, each containing host name, result (success of failure)
      *      and error message (if any).
      * @throws GridException In case of error.
      */
     public Collection<GridTuple3<String, Boolean, String>> startNodes(File file, boolean restart,
-        int timeout, int maxConn) throws GridException;
+        int timeout, int maxConn) throws IgniteCheckedException;
 
     /**
      * Starts one or more nodes on remote host(s).
@@ -265,10 +265,10 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @param maxConn Number of parallel SSH connections to one host.
      * @return Collection of tuples, each containing host name, result (success of failure)
      *      and error message (if any).
      * @throws GridException In case of error.
      */
     public Collection<GridTuple3<String, Boolean, String>> startNodes(Collection<Map<String, Object>> hosts,
-        @Nullable Map<String, Object> dflts, boolean restart, int timeout, int maxConn) throws GridException;
+        @Nullable Map<String, Object> dflts, boolean restart, int timeout, int maxConn) throws IgniteCheckedException;
 
     /**
      * Stops nodes satisfying optional set of predicates.
@@ -277,9 +277,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * stopping node. If you have other applications running in the same JVM along with GridGain,
      * those applications will be stopped as well.
      *
      * @throws GridException In case of error.
      */
-    public void stopNodes() throws GridException;
+    public void stopNodes() throws IgniteCheckedException;
 
     /**
      * Stops nodes defined by provided IDs.
@@ -289,9 +289,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * those applications will be stopped as well.
      *
      * @param ids IDs defining nodes to stop.
      * @throws GridException In case of error.
      */
-    public void stopNodes(Collection<UUID> ids) throws GridException;
+    public void stopNodes(Collection<UUID> ids) throws IgniteCheckedException;
 
     /**
      * Restarts nodes satisfying optional set of predicates.
@@ -299,9 +299,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * <b>NOTE:</b> this command only works for grid nodes started with GridGain
      * {@code ggstart.sh} or {@code ggstart.bat} scripts.
      *
      * @throws GridException In case of error.
      */
-    public void restartNodes() throws GridException;
+    public void restartNodes() throws IgniteCheckedException;
 
     /**
      * Restarts nodes defined by provided IDs.
@@ -310,9 +310,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * {@code ggstart.sh} or {@code ggstart.bat} scripts.
      *
      * @param ids IDs defining nodes to restart.
      * @throws GridException In case of error.
      */
-    public void restartNodes(Collection<UUID> ids) throws GridException;
+    public void restartNodes(Collection<UUID> ids) throws IgniteCheckedException;
 
     /**
      * Resets local I/O, job, and task execution metrics.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
----------------------------------------------------------------------
@@ -111,10 +111,10 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @param keys Cache keys to map to nodes.
      * @return Map of nodes to cache keys or empty map if there are no alive nodes for this cache.
-     * @throws GridException If failed to map cache keys.
+     * @throws IgniteCheckedException If failed to map cache keys.
      */
     public <K> Map<ClusterNode, Collection<K>> mapKeysToNodes(@Nullable String cacheName,
@@ -135,9 +135,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @return Primary node for the key or {@code null} if cache with given name
      *      is not present in the grid.
-     * @throws GridException If failed to map key.
+     * @throws IgniteCheckedException If failed to map key.
      */
@@ -164,10 +164,10 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @return Collection of tuples, each containing host name, result (success of failure)
      *      and error message (if any).
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public Collection<GridTuple3<String, Boolean, String>> startNodes(File file, boolean restart,
@@ -265,10 +265,10 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * @return Collection of tuples, each containing host name, result (success of failure)
      *      and error message (if any).
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public Collection<GridTuple3<String, Boolean, String>> startNodes(Collection<Map<String, Object>> hosts,
@@ -277,9 +277,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * those applications will be stopped as well.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -289,9 +289,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      *
      * @param ids IDs defining nodes to stop.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -299,9 +299,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      * {@code ggstart.sh} or {@code ggstart.bat} scripts.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -310,9 +310,9 @@ public interface IgniteCluster extends ClusterGroup, IgniteAsyncSupport {
      *
      * @param ids IDs defining nodes to restart.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java b/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
index 39818ee..613a521 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
@@ -114,9 +114,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job which will be co-located on the node with given affinity key.
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
      * @throws GridException If job failed.
      */
-    public void affinityRun(@Nullable String cacheName, Object affKey, Runnable job) throws GridException;
+    public void affinityRun(@Nullable String cacheName, Object affKey, Runnable job) throws IgniteCheckedException;
 
     /**
      * Executes given job on the node where data for provided affinity key is located
@@ -128,11 +128,11 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param affKey Affinity key.
      * @param job Job which will be co-located on the node with given affinity key.
      * @return Job result.
      * @throws GridException If job failed.
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
      */
-    public <R> R affinityCall(@Nullable String cacheName, Object affKey, Callable<R> job) throws GridException;
+    public <R> R affinityCall(@Nullable String cacheName, Object affKey, Callable<R> job) throws IgniteCheckedException;
 
     /**
      * Executes given task on the grid projection. For step-by-step explanation of task execution process
@@ -145,9 +145,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *      class name is used as task name.
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
      * @throws GridException If task failed.
      */
-    public <T, R> R execute(Class<? extends ComputeTask<T, R>> taskCls, @Nullable T arg) throws GridException;
+    public <T, R> R execute(Class<? extends ComputeTask<T, R>> taskCls, @Nullable T arg) throws IgniteCheckedException;
 
     /**
      * Executes given task on this grid projection. For step-by-step explanation of task execution process
@@ -160,9 +160,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *      class name is used as task name.
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
      * @throws GridException If task failed.
      */
-    public <T, R> R execute(ComputeTask<T, R> task, @Nullable T arg) throws GridException;
+    public <T, R> R execute(ComputeTask<T, R> task, @Nullable T arg) throws IgniteCheckedException;
 
     /**
      * Executes given task on this grid projection. For step-by-step explanation of task execution process
@@ -176,10 +176,10 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param taskName Name of the task to execute.
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
      * @throws GridException If task failed.
      * @see org.apache.ignite.compute.ComputeTask for information about task execution.
      */
-    public <T, R> R execute(String taskName, @Nullable T arg) throws GridException;
+    public <T, R> R execute(String taskName, @Nullable T arg) throws IgniteCheckedException;
 
     /**
      * Broadcasts given job to all nodes in grid projection.
@@ -187,9 +187,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * Supports asynchronous execution (see {@link IgniteAsyncSupport}).
      *
      * @param job Job to broadcast to all projection nodes.
      * @throws GridException If job failed.
      */
-    public void broadcast(Runnable job) throws GridException;
+    public void broadcast(Runnable job) throws IgniteCheckedException;
 
     /**
      * Broadcasts given job to all nodes in grid projection. Every participating node will return a
@@ -199,9 +199,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job to broadcast to all projection nodes.
      * @return Collection of results for this execution.
      * @throws GridException If execution failed.
      */
-    public <R> Collection<R> broadcast(Callable<R> job) throws GridException;
+    public <R> Collection<R> broadcast(Callable<R> job) throws IgniteCheckedException;
 
     /**
      * Broadcasts given closure job with passed in argument to all nodes in grid projection.
@@ -213,9 +213,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to broadcast to all projection nodes.
      * @param arg Job closure argument.
      * @return Collection of results for this execution.
      * @throws GridException If execution failed.
      */
-    public <R, T> Collection<R> broadcast(IgniteClosure<T, R> job, @Nullable T arg) throws GridException;
+    public <R, T> Collection<R> broadcast(IgniteClosure<T, R> job, @Nullable T arg) throws IgniteCheckedException;
 
     /**
      * Executes provided job on a node in this grid projection.
@@ -223,9 +223,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * Supports asynchronous execution (see {@link IgniteAsyncSupport}).
      *
      * @param job Job closure to execute.
      * @throws GridException If execution failed.
      */
-    public void run(Runnable job) throws GridException;
+    public void run(Runnable job) throws IgniteCheckedException;
 
     /**
      * Executes collection of jobs on grid nodes within this grid projection.
@@ -233,9 +233,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * Supports asynchronous execution (see {@link IgniteAsyncSupport}).
      *
      * @param jobs Collection of jobs to execute.
      * @throws GridException If execution failed.
      */
-    public void run(Collection<? extends Runnable> jobs) throws GridException;
+    public void run(Collection<? extends Runnable> jobs) throws IgniteCheckedException;
 
     /**
      * Executes provided job on a node in this grid projection. The result of the
@@ -245,9 +245,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job to execute.
      * @return Job result.
      * @throws GridException If execution failed.
      */
-    public <R> R call(Callable<R> job) throws GridException;
+    public <R> R call(Callable<R> job) throws IgniteCheckedException;
 
     /**
      * Executes collection of jobs on nodes within this grid projection.
@@ -257,9 +257,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param jobs Collection of jobs to execute.
      * @return Collection of job results for this execution.
      * @throws GridException If execution failed.
      */
-    public <R> Collection<R> call(Collection<? extends Callable<R>> jobs) throws GridException;
+    public <R> Collection<R> call(Collection<? extends Callable<R>> jobs) throws IgniteCheckedException;
 
     /**
      * Executes collection of jobs on nodes within this grid projection. The returned
@@ -270,9 +270,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param jobs Collection of jobs to execute.
      * @param rdc Reducer to reduce all job results into one individual return value.
      * @return Future with reduced job result for this execution.
      * @throws GridException If execution failed.
      */
-    public <R1, R2> R2 call(Collection<? extends Callable<R1>> jobs, IgniteReducer<R1, R2> rdc) throws GridException;
+    public <R1, R2> R2 call(Collection<? extends Callable<R1>> jobs, IgniteReducer<R1, R2> rdc) throws IgniteCheckedException;
 
     /**
      * Executes provided closure job on a node in this grid projection. This method is different
@@ -284,9 +284,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to run.
      * @param arg Job argument.
      * @return Job result.
      * @throws GridException If execution failed.
      */
-    public <R, T> R apply(IgniteClosure<T, R> job, @Nullable T arg) throws GridException;
+    public <R, T> R apply(IgniteClosure<T, R> job, @Nullable T arg) throws IgniteCheckedException;
 
     /**
      * Executes provided closure job on nodes within this grid projection. A new job is executed for
@@ -298,9 +298,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to run.
      * @param args Job arguments.
      * @return Collection of job results.
      * @throws GridException If execution failed.
      */
-    public <T, R> Collection<R> apply(IgniteClosure<T, R> job, Collection<? extends T> args) throws GridException;
+    public <T, R> Collection<R> apply(IgniteClosure<T, R> job, Collection<? extends T> args) throws IgniteCheckedException;
 
     /**
      * Executes provided closure job on nodes within this grid projection. A new job is executed for
@@ -314,10 +314,10 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param args Job arguments.
      * @param rdc Reducer to reduce all job results into one individual return value.
      * @return Future with reduced job result for this execution.
      * @throws GridException If execution failed.
      */
     public <R1, R2, T> R2 apply(IgniteClosure<T, R1> job, Collection<? extends T> args,
-        IgniteReducer<R1, R2> rdc) throws GridException;
+        IgniteReducer<R1, R2> rdc) throws IgniteCheckedException;
 
     /**
      * Gets tasks future for active tasks started on local node.
@@ -396,9 +396,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *      class name will be used as task's name.
      * @param clsLdr Task class loader. This class loader is in charge
      *      of loading all necessary resources for task execution.
      * @throws GridException If task is invalid and cannot be deployed.
      */
-    public void localDeployTask(Class<? extends ComputeTask> taskCls, ClassLoader clsLdr) throws GridException;
+    public void localDeployTask(Class<? extends ComputeTask> taskCls, ClassLoader clsLdr) throws IgniteCheckedException;
 
     /**
      * Gets map of all locally deployed tasks keyed by their task name .
@@ -413,9 +413,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * undeployed on every node.
      *
      * @param taskName Name of the task to undeploy.
      * @throws GridException Thrown if undeploy failed.
      */
-    public void undeployTask(String taskName) throws GridException;
+    public void undeployTask(String taskName) throws IgniteCheckedException;
 
     /** {@inheritDoc} */
     @Override public <R> ComputeTaskFuture<R> future();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
----------------------------------------------------------------------
@@ -114,9 +114,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
-     * @throws GridException If job failed.
+     * @throws IgniteCheckedException If job failed.
      */
@@ -128,11 +128,11 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job which will be co-located on the node with given affinity key.
      * @return Job result.
-     * @throws GridException If job failed.
+     * @throws IgniteCheckedException If job failed.
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
@@ -145,9 +145,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
-     * @throws GridException If task failed.
+     * @throws IgniteCheckedException If task failed.
      */
@@ -160,9 +160,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
-     * @throws GridException If task failed.
+     * @throws IgniteCheckedException If task failed.
      */
@@ -176,10 +176,10 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
-     * @throws GridException If task failed.
+     * @throws IgniteCheckedException If task failed.
      * @see org.apache.ignite.compute.ComputeTask for information about task execution.
      */
@@ -187,9 +187,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job to broadcast to all projection nodes.
-     * @throws GridException If job failed.
+     * @throws IgniteCheckedException If job failed.
      */
@@ -199,9 +199,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to broadcast to all projection nodes.
      * @return Collection of results for this execution.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -213,9 +213,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Job closure argument.
      * @return Collection of results for this execution.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -223,9 +223,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job closure to execute.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -233,9 +233,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param jobs Collection of jobs to execute.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -245,9 +245,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to execute.
      * @return Job result.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -257,9 +257,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param jobs Collection of jobs to execute.
      * @return Collection of job results for this execution.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -270,9 +270,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param rdc Reducer to reduce all job results into one individual return value.
      * @return Future with reduced job result for this execution.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -284,9 +284,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Job argument.
      * @return Job result.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -298,9 +298,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param args Job arguments.
      * @return Collection of job results.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
@@ -314,10 +314,10 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param rdc Reducer to reduce all job results into one individual return value.
      * @return Future with reduced job result for this execution.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
     public <R1, R2, T> R2 apply(IgniteClosure<T, R1> job, Collection<? extends T> args,
@@ -396,9 +396,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param clsLdr Task class loader. This class loader is in charge
      *      of loading all necessary resources for task execution.
-     * @throws GridException If task is invalid and cannot be deployed.
+     * @throws IgniteCheckedException If task is invalid and cannot be deployed.
      */
@@ -413,9 +413,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param taskName Name of the task to undeploy.
-     * @throws GridException Thrown if undeploy failed.
+     * @throws IgniteCheckedException Thrown if undeploy failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java b/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
index 2f38d1d..ecedb0f 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
@@ -109,9 +109,9 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * Default is {@code false}.
      *
      * @param isolated Flag value.
      * @throws GridException If failed.
      */
-    public void isolated(boolean isolated) throws GridException;
+    public void isolated(boolean isolated) throws IgniteCheckedException;
 
     /**
      * Gets size of per node key-value pairs buffer.
@@ -213,12 +213,12 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      *
      * @param key Key.
      * @return Future fo this operation.
      * @throws GridException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      */
-    public IgniteFuture<?> removeData(K key)  throws GridException, GridInterruptedException, IllegalStateException;
+    public IgniteFuture<?> removeData(K key)  throws IgniteCheckedException, GridInterruptedException, IllegalStateException;
 
     /**
      * Adds data for loading on remote node. This method can be called from multiple
@@ -231,12 +231,12 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * @param key Key.
      * @param val Value or {@code null} if respective entry must be removed from cache.
      * @return Future fo this operation.
      * @throws GridException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      */
-    public IgniteFuture<?> addData(K key, @Nullable V val) throws GridException, GridInterruptedException,
+    public IgniteFuture<?> addData(K key, @Nullable V val) throws IgniteCheckedException, GridInterruptedException,
         IllegalStateException;
 
     /**
@@ -249,12 +249,12 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      *
      * @param entry Entry.
      * @return Future fo this operation.
      * @throws GridException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      */
-    public IgniteFuture<?> addData(Map.Entry<K, V> entry) throws GridException, GridInterruptedException,
+    public IgniteFuture<?> addData(Map.Entry<K, V> entry) throws IgniteCheckedException, GridInterruptedException,
         IllegalStateException;
 
     /**
@@ -296,34 +296,34 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * another thread to complete flush and exit. If you don't want to wait in this case,
      * use {@link #tryFlush()} method.
      *
      * @throws GridException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      * @see #tryFlush()
      */
-    public void flush() throws GridException, GridInterruptedException, IllegalStateException;
+    public void flush() throws IgniteCheckedException, GridInterruptedException, IllegalStateException;
 
     /**
      * Makes an attempt to load remaining data. This method is mostly similar to {@link #flush},
      * with the difference that it won't wait and will exit immediately.
      *
      * @throws GridException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      * @see #flush()
      */
-    public void tryFlush() throws GridException, GridInterruptedException, IllegalStateException;
+    public void tryFlush() throws IgniteCheckedException, GridInterruptedException, IllegalStateException;
 
     /**
      * Loads any remaining data and closes this loader.
      *
      * @param cancel {@code True} to cancel ongoing loading operations.
      * @throws GridException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      */
-    public void close(boolean cancel) throws GridException, GridInterruptedException;
+    public void close(boolean cancel) throws IgniteCheckedException, GridInterruptedException;
 
     /**
      * Closes data loader. This method is identical to calling {@link #close(boolean) close(false)} method.
@@ -331,8 +331,8 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * The method is invoked automatically on objects managed by the
      * {@code try-with-resources} statement.
      *
      * @throws GridException If failed to close data loader.
      * @throws GridInterruptedException If thread has been interrupted.
      */
-    @Override public void close() throws GridException, GridInterruptedException;
+    @Override public void close() throws IgniteCheckedException, GridInterruptedException;
 }
@@ -109,9 +109,9 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      *
      * @param isolated Flag value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -213,12 +213,12 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * @param key Key.
      * @return Future fo this operation.
-     * @throws GridException If failed to map key to node.
+     * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
@@ -231,12 +231,12 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * @param val Value or {@code null} if respective entry must be removed from cache.
      * @return Future fo this operation.
-     * @throws GridException If failed to map key to node.
+     * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
@@ -249,12 +249,12 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * @param entry Entry.
      * @return Future fo this operation.
-     * @throws GridException If failed to map key to node.
+     * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
@@ -296,34 +296,34 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * use {@link #tryFlush()} method.
      *
-     * @throws GridException If failed to map key to node.
+     * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
@@ -296,34 +296,34 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * with the difference that it won't wait and will exit immediately.
      *
-     * @throws GridException If failed to map key to node.
+     * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
@@ -296,34 +296,34 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      *
      * @param cancel {@code True} to cancel ongoing loading operations.
-     * @throws GridException If failed to map key to node.
+     * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      */
@@ -331,8 +331,8 @@ public interface IgniteDataLoader<K, V> extends AutoCloseable {
      * {@code try-with-resources} statement.
      *
-     * @throws GridException If failed to close data loader.
+     * @throws IgniteCheckedException If failed to close data loader.
      * @throws GridInterruptedException If thread has been interrupted.
      */